;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Loading this file installs CG/JS.
;; Please see readme.txt for more information
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(in-package :user)

(eval-when (compile eval load)
  (require :shell)
  (use-package :excl.shell))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; validate files

(let ((platform-file
       (directory
	(merge-pathnames
	 "PLATFORM-*"
	 (path-pathname *load-pathname*)))))
  (or platform-file
      (error "Could not find the PLATFORM file."))
  
  (when (> (length platform-file) 1)
    (error "There is more than one PLATFORM file: ~a." platform-file))
  (setq platform-file (car platform-file))
  
  (or (=~ "^PLATFORM-(.*)" (file-namestring platform-file))
      (error "Cannot parse the PLATFORM file."))
  
  (let ((expected-platform $1)
	(current-platform
	 (format nil "~a~a" (symbol-name sys::.os.) #+smp "smp" #-smp "")))
    (or (string-equal expected-platform current-platform)
	(error
	 "The current platform (~a) does not match the downloaded version (~a)."
	 current-platform expected-platform)))
  ;; We are on the correct platform, fall through...
  )

;; HTML files needed for the operation of CG/JS
;; (this variable's value is generated by build_cgjs.sh)
(defvar *html-files* '("cgjs.html" "ssl-not-found.html" "browser-not-supported.html" ))

(defvar *extra-files*)
(setq *extra-files* nil)

(dolist (file *html-files*)
  (setq file (merge-pathnames file *load-pathname*))
  (or (probe-file file)
      (error "~a does not exist." file))
  (push file *extra-files*))
;; All *html-files* exist...

;; These two are directories but the pathname is specified as
;; a file, so merging works below.
(defvar *cg2js-directory* (merge-pathnames "code.cg2js" *load-pathname*))
(defvar *idejs-directory* (merge-pathnames "code.idejs" *load-pathname*))

(dolist (d (list *cg2js-directory* *idejs-directory*))
  (or (probe-file d)
      (error "~a does not exist." d)))

;; MD5 checksums of the incoming files
;; (this variable's value is generated by build_cgjs.sh)
(defvar *checksums* 
'(
(#xe1e5e2017015d2b06ebfc5bb54bb9bf5 . "./code.cg2js/cg-common-control.fasl")
(#xc8ec09248a65f700106b19015fbfc4e0 . "./code.cg2js/cg-clipboard-stack.fasl")
(#x01e39433d803f8c2c44fdaf375321b3b . "./code.cg2js/cg-yes-no-string.fasl")
(#xb3c7d9c6324c3347da2b803047b65da5 . "./code.cg2js/cg-clipboard.fasl")
(#xe9c91fc9ab3dea204804b212d0e120e9 . "./code.cg2js/cg-dde-utils.fasl")
(#x90b9c1c48fe5b314a45921c0ba7f01c3 . "./code.cg2js/cg-editable-text.fasl")
(#x0bb59ee747223512c2cfcfceb723e068 . "./code.cg2js/cg-text-or-combo.fasl")
(#x1044b563a7a22f7e1ff12bff24dc8fc8 . "./code.cg2js/cg-picture-widget-palette.fasl")
(#xed851fbaa85ff3201756eb14b43f81a6 . "./code.cg2js/cg-graphics-context.fasl")
(#x1e54293895aa965be21c36b515bb7145 . "./code.cg2js/cg-choose-printer.fasl")
(#x169665b96398bea99d541081973e6593 . "./code.cg2js/cg-scroll-bar-mixin.fasl")
(#xe151c7c0f43f50acec83ab5aee375d7e . "./code.cg2js/cg-edit-in-place.fasl")
(#xc0a3a7740458893fad5b77d6d99908ad . "./code.cg2js/cg-split-bar.fasl")
(#x293aca097f6a73bfd704508f9fe36087 . "./code.cg2js/cg-timer.fasl")
(#xe2adedc006896dfa7da7bb615fe260eb . "./code.cg2js/cg-progress-indicator.fasl")
(#xa8236bc47b9faa0c5a84976c81494f28 . "./code.cg2js/cg-object-editor.fasl")
(#x8a5fdbfdd376190a00e45726c5be45f5 . "./code.cg2js/cg-fill-texture.fasl")
(#xc89e60816c2811a55b2f567870380247 . "./code.cg2js/cg-multi-picture-button-drag-and-drop.fasl")
(#x224e159fccf4beab7c92f472d3461d98 . "./code.cg2js/cg-os-window.fasl")
(#x568b82d319cbf3f170153895696ccedf . "./code.cg2js/cg-color-dialog.fasl")
(#x8fce343d666efa53c1ef20c8136862a4 . "./code.cg2js/cg-combo-box.fasl")
(#x4ecf7133010cebde23b303c6fb90b4e4 . "./code.cg2js/cg-directory-dialog.fasl")
(#xea8ac67c253fef8466341637bbcc69ef . "./code.cg2js/cg-rich-edit-pane.fasl")
(#x50a3cf0407448f530e8af8f58c8c894f . "./code.cg2js/cg-tooltip.fasl")
(#x1df49ba80d73704394e4ba91b6713f51 . "./code.cg2js/cg-lettered-menu.fasl")
(#xf89837785c4f7e478e416ab5b71ddca1 . "./code.cg2js/cg-clipboard-pixmap.fasl")
(#xab50e6322a6723f0d02b81f727fa8d98 . "./code.cg2js/cg-pixmap.fasl")
(#x39f8c0df81543a15a56613cfc93fe529 . "./code.cg2js/cg.fasl")
(#x7d952383c458020c0af77a5a62ce9a94 . "./code.cg2js/cg-class-slot-grid.fasl")
(#xd5bb9f83c6a49ce4bd3fd5fd1f12db83 . "./code.cg2js/cg-template-string.fasl")
(#x0420ba201a5d37ad50d28ee48697267f . "./code.cg2js/cg-text-edit-pane-mark.fasl")
(#x2ac7bab3c77a14aec6af7d68fb2c4a74 . "./code.cg2js/cg-check-box.fasl")
(#xe89a7286d2326dd9caebd6da948b28fd . "./code.cg2js/cg-toggling-widget.fasl")
(#xec7d1ba8f0c8ee9b541613cccaf3de53 . "./code.cg2js/cg-radio-button.fasl")
(#x9e20d91ff1a5a7c1b3cc4c77bd7b9264 . "./code.cg2js/cg-directory-dialog-os.fasl")
(#x7394f9e39fb0caf124ea9c00ffccb5a0 . "./code.cg2js/cg-scaling-stream.fasl")
(#x7fb84520dbe00a5ce6c5a33cf457d0e5 . "./code.cg2js/cg-multi-picture-button.fasl")
(#x4979a8c89d9bd4496405e9d2d9943112 . "./code.cg2js/cg-multi-line-editable-text.fasl")
(#x9045eea3bdb6b1e1383da725b9fa4892 . "./code.cg2js/cg-grid-widget.fasl")
(#x0cdfbd57bc0cbcf7a091d4762667f634 . "./code.cg2js/cg-text-edit-pane.fasl")
(#xa814d15891459af892c18ebea7c2ec9f . "./code.cg2js/cg-item-list.fasl")
(#x5a387dad24b4827d3154018d5c3ff6d6 . "./code.cg2js/cg-paren-matching.fasl")
(#x83f602611d26d92fb77c56ae94ca331e . "./code.cg2js/cg-multi-picture-button-tooltip.fasl")
(#xe91a4905270d9506ba1b1b9bf06034b4 . "./code.cg2js/cg-html-dialog.fasl")
(#x27c305651de6b6733edc5cce79c27e2f . "./code.cg2js/cg-pixmap-widget.fasl")
(#x2c0aa9f3fd2353a53a15afebe1719a17 . "./code.cg2js/cg-project-window.fasl")
(#xd152e5aa4b044d6d1a5902bdee21c658 . "./code.cg2js/cg-rich-edit-pane-clipboard.fasl")
(#x74c9d106264442549dfbefbbbc349e7c . "./code.cg2js/cg-toolbar.fasl")
(#xc24b9f6eefcdc4371e62db6371ad948e . "./code.cg2js/cg-caret.fasl")
(#x141a81f7b8fe0f285181227a6cf13fe2 . "./code.cg2js/cg-scroll-bar.fasl")
(#x92d36cfad23b2e4dd35fb6db4f155a00 . "./code.cg2js/cg-web-browser.fasl")
(#x91006fa040c44c560f6a86e94b2dc960 . "./code.cg2js/cg-dropping-outline.fasl")
(#xd508a7f98652f7b9547bfba7cdb091ad . "./code.cg2js/cg-font-dialog.fasl")
(#x2f1d69ed6014062bd6a55ed44208a5d9 . "./code.cg2js/cg-icon-pixmap.fasl")
(#x4fb297e7ef2cc82c31e4258c0fca4433 . "./code.cg2js/cg-yes-no-list.fasl")
(#x80c90b2f542073c38100e4f3fcbce414 . "./code.cg2js/cg-lisp-edit-pane.fasl")
(#x9cb4a25e5bab1d3757b671b61d2976d8 . "./code.cg2js/cg-lamp.fasl")
(#xc4a4b3811b134717073d2a4bcc65b4ca . "./code.cg2js/cg-drawable.fasl")
(#xd810f89ce8d2382f1c17bef88ea97b8f . "./code.cg2js/cg-choice-list.fasl")
(#xb2d98fdfb9b754a6b737744cb1253a96 . "./code.cg2js/cg-curve.fasl")
(#xe49689cdce47a9ce5f7d9da804220dc8 . "./code.cg2js/cg-base.fasl")
(#x6df916ef6f7f7df0f1f07da4b3fced00 . "./code.cg2js/cg-keyboard-shortcuts.fasl")
(#x7225c8eb7b310ee3205547c55bbb5d68 . "./code.cg2js/cg-printing.fasl")
(#x36922f2a8db61a7dab89d81e906a3246 . "./code.cg2js/cg-chart-or-plot.fasl")
(#xc7a06e99d93bf3e99d665114256dd67c . "./code.cg2js/cg-hotspot.fasl")
(#x62f0f9683990dee278605bff9307b65d . "./code.cg2js/cg-object-editor-layout.fasl")
(#x01dc32785266bc22ff2d95fa48a02797 . "./code.cg2js/cg-utility-dialog.fasl")
(#xc6f6641ec7fcaa142cd303b4892d805d . "./code.cg2js/cg-shortcut-menu.fasl")
(#xb708a2e1a80307b6fc86a9a118114530 . "./code.cg2js/cg-comtab.fasl")
(#x830608ec4c0e125c0e3ec27c982cf768 . "./code.cg2js/cg-os-widget.fasl")
(#x1f05a1bc9760a48cfaacb7a8c3fc8968 . "./code.cg2js/cg-icon.fasl")
(#x73f6c25c6c1fdb834a5a09dbbc9890d4 . "./code.cg2js/cg-dev.fasl")
(#x0d854d574220462b5299c4a500555ad6 . "./code.cg2js/cg-calendar.fasl")
(#x1d6144298032106b203abb2f14c19ec3 . "./code.cg2js/cg-group-box.fasl")
(#xbe21a3e1ce05beb3ff4c0a5516075108 . "./code.cg2js/cg-grid-widget-drag-and-drop.fasl")
(#x30e2b601b8fd9c6d47e8c864841260da . "./code.cg2js/cg-bitmap-pane.fasl")
(#xc7f994b7c140e7b7f377a31c5c4ddb49 . "./code.cg2js/cg-drag-and-drop.fasl")
(#x30186bd0b99da1d8ec2c40a321093a3d . "./code.cg2js/cg-nodes.fasl")
(#x70d320a590b6150e3e872f6e075d5370 . "./code.cg2js/cg-intersect.fasl")
(#xfbdc6f5b3304e90babdeaa25ca0db7c8 . "./code.cg2js/cg-outline-drag-and-drop.fasl")
(#xc8766722f07ad0726a64f3eb61ee1c4d . "./code.cg2js/cg-rich-edit-pane-printing.fasl")
(#xb3f3e987404dae4c46b31109df1dc2fc . "./code.cg2js/cg-class-support.fasl")
(#xe3e9c914454fcbac699f615b78329885 . "./code.cg2js/cg-dialog-item.fasl")
(#x12cf80415a7a63b0e5a967e23790ba44 . "./code.cg2js/cg-plot-widget.fasl")
(#x67d6ab120984a70adee9711d47090a78 . "./code.cg2js/cg-pixmap-printing.fasl")
(#x3983b1c5a3945638c7715320164bc176 . "./code.cg2js/cg-up-down-control.fasl")
(#xd11ac073e9a3d95e76447aa3becb6dae . "./code.cg2js/cg-rich-edit.fasl")
(#xd11f98bf82aab471fdf3bfab9f932f14 . "./code.cg2js/cg-drag-and-drop-image.fasl")
(#xf2e18ac2c35cb8a04362adbdcc7239aa . "./code.cg2js/cg-status-bar.fasl")
(#xd7276193be3391ff820b24cfbb7ce942 . "./code.cg2js/cg-class-grid.fasl")
(#x0fbb8d6a6db62d48f5e80245658a4304 . "./code.cg2js/cg-wrap-string.fasl")
(#x64ec875af196a213cb65cfd31d393a56 . "./code.cg2js/cg-layout.fasl")
(#x20c4ea12021aa0a46a3cbaf6ef8fdd7c . "./code.cg2js/cg-lisp-widget.fasl")
(#x758231b173aefdfe90ec46cab60ca73b . "./code.cg2js/cg-button.fasl")
(#xc9706f4d962c4d8682d4f1bb62951aec . "./code.cg2js/cg-string-dialog.fasl")
(#x1c4ce8ec9869cc9b901bbd0d60b7bea7 . "./code.cg2js/cg-pixmap-rotate.fasl")
(#x20d78418929b13a0bedff3786105cfa5 . "./code.cg2js/cg-outline-edit-in-place.fasl")
(#xfa6c7cec78b3c6478d90285edfd8bf76 . "./code.cg2js/cg-bitmap-stream.fasl")
(#x552da9529dbe97e97e293b984f789963 . "./code.cg2js/cg-static-text.fasl")
(#x28294ca1df4b3317e9cc90a6cef98979 . "./code.cg2js/cg-outline.fasl")
(#xd470d8f0e111103a5c44d739d0bd26b9 . "./code.cg2js/cg-gesture-emulation.fasl")
(#xdb1782d64c01fdc1bd512a2537aa6008 . "./code.cg2js/cg-bitmap-pane-clipboard.fasl")
(#xc8a6e999d833f595b2547bc2b04bc079 . "./code.cg2js/cg-picture-widget.fasl")
(#x4a62d2d0f7622df6c2255a92f1d7acb1 . "./code.cg2js/cg-multi-line-lisp-text.fasl")
(#x17004c36128bfca20734275f4fe11b1b . "./code.cg2js/cg-chart-widget.fasl")
(#xd144b45e041f4d563f73aba380e0a32e . "./code.cg2js/cg-cursor-pixmap.fasl")
(#x94e3b439cf5f2f8805709e49482bed71 . "./code.cg2js/cg-lisp-text.fasl")
(#x46fc7aedb703066f2ff77d60a228b36e . "./code.cg2js/cg-palette.fasl")
(#x28709a447781aae9dd0ca07b76c9c08e . "./code.cg2js/cg-property.fasl")
(#x06d3007f1a7f9cb5ff091670e59af94a . "./code.cg2js/cg-intersect-posbox.fasl")
(#x9bdff7368c3692f87a7b3c538b3fda30 . "./code.cg2js/cg-file-dialog.fasl")
(#x55172d51675ba9ba2fc15b15a3179bc5 . "./code.cg2js/cg-text-edit-pane-file-io.fasl")
(#xd970b4b2aff374f3820dd87387e8409f . "./code.cg2js/cg-get-pixmap.fasl")
(#x3812dded12b20fc2fe1adc36604fb087 . "./code.cg2js/cg-tray.fasl")
(#x89be16f6c39285fcf3e03248d22ecd39 . "./code.cg2js/cg-acache.fasl")
(#x545c392b0075d92997fe60a3915dc858 . "./code.cg2js/cg-message-dialog.fasl")
(#x42a9a9b7748b83e7f956b7e77d070c19 . "./code.cg2js/cg-pixmap-file-io.fasl")
(#x326c0787dc81a0f9c706821a59446241 . "./code.cg2js/cg-drawable-clipboard.fasl")
(#x1f1a0b13f7eb7052f1a4757b95f0144e . "./code.cg2js/cg-tab-control.fasl")
(#x494b5175e66c6ed5a5bff97ffb9eb940 . "./code.cg2js/cg-scrolling-static-text.fasl")
(#x95a8c26f78d2d35fea2eb498f52b1d31 . "./code.cg2js/cg-menu-tooltip.fasl")
(#x717886539e3ad5c0d7ef1a6f2f74fc6e . "./code.cg2js/cg-find-string-dialog.fasl")
(#x7618fc0dc8cf732a2a69cd0bd5fa5c2f . "./code.cg2js/cg-menu.fasl")
(#xc1f0fe6c203d6623dffa78857a69eea4 . "./code.cg2js/cg-get-position.fasl")
(#x11189ecc4a49a90441e257642c5f120d . "./code.cg2js/cg-trackbar.fasl")
(#x3c18c511f6adad425bce3d2ba4cffeb6 . "./code.cg2js/cg-selected-object.fasl")
(#x4e9a5957c5a284b36b9871db6f0e1204 . "./code.cg2js/cg-list-view.fasl")
(#x810d67aaa80f8d0be686826b53e63ebd . "./code.cg2js/cg-html-widget.fasl")
(#x03328617cc576151beac12615aa0dbe9 . "./code.cg2js/cg-sample-file-menu.fasl")
(#x49060676d318741f189c20d7b4bab558 . "./code.cg2js/cg-text-widget.fasl")
(#x6f145828fe76b77164bc2a3dd17233d2 . "./code.idejs/ide-base.fasl")
(#xb56bb6abd0ac7d11d069186f90343ccd . "./code.idejs/ide-process-browser.fasl")
(#x1ba2546c4ee39f09b53d35f29e256641 . "./code.idejs/ide-patch-dialog.fasl")
(#xdf817a3b99284d22aa21ed0ac1c4985b . "./code.idejs/ide-keyshort.fasl")
(#x8d0ed02451890a6a8b30023ee1d20bee . "./code.idejs/ide-window-list.fasl")
(#x07aedac53467b446ac90268d2b05e2c1 . "./code.idejs/ide.fasl")
(#xd5b1b4c96f2aeb375fea46bf9ae0d18d . "./code.idejs/ide-editor.fasl")
(#x4755fcf7f9c0babedcbac7869595085b . "./code.idejs/ide-clipboard.fasl")
(#x4549d2905f6335e0e5a4eb7f3e60514c . "./code.idejs/ide-trace.fasl")
(#xe0a4f71254c56f4672e2c2b89df68ecd . "./code.idejs/ide-class-browser.fasl")
(#x6911d2400dbfef9d3a2bf54f6b38c367 . "./code.idejs/ide-grapher.fasl")
(#xd58ff23155ac97abed4b69aaefca0ab9 . "./code.idejs/ide-apropos.fasl")
(#x7d27f5455c70d166624e83293f06c416 . "./code.idejs/ide-navigator.fasl")
(#x5d870751d352d06c06b9a7dc5696daf6 . "./code.idejs/ide-find-definitions.fasl")
(#x05610f3d0b4e193410795bcd81b9e054 . "./code.idejs/ide-project.fasl")
(#x28f7213387954ba1ea2824bb0e53a737 . "./code.idejs/ide-class-grapher.fasl")
(#xcea5b8799ad13f78a8d57994c9af7a65 . "./code.idejs/ide-acache.fasl")
(#x705580845dc98fb07286dced215c6b80 . "./code.idejs/ide-find-in-files.fasl")
(#xb3f6aeef2023be620ec8077726021ce2 . "./code.idejs/ide-inspector.fasl")
(#x3fc3bf94fdc9153e8d8678a69755331a . "./code.idejs/ide-intro.fasl")
(#xef58e6bed36f030bf20b1866541b725a . "./code.idejs/ide-package-list.fasl")
(#xfe2ddbca3490c676a1068b708ce66afa . "./code.idejs/ide-dev.fasl")
(#x2b95e454c57cd330cc97ea44cf49f815 . "./code.idejs/ide-form.fasl")
(#x696b64509ebe0538a3b58ac1081d4fa0 . "./cgjs.html")
(#x34779e5d4bbb71d45bf63f88fac54100 . "./ssl-not-found.html")
(#x90c6d2a65504d45266ad9fa3a49be2f9 . "./browser-not-supported.html"))
 )

(let ((files-ok
       (dolist (checksum *checksums* t)
	 (when (/= (car checksum)
		   (md5-file
		    (merge-pathnames (cdr checksum) *load-pathname*)))
	   (return nil)))))
  (cond
   ((not files-ok)
    (error "The extracted files failed the checksum test.  ~
Please download and/or extract again."))
   (t
    (format t "Checksums on files are OK...~%"))))

;; We have validated all the files are there...

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; check for needed patches

(eval-when (compile eval load) (require :build))

(defvar *required-patches* '(#+macosx ("build" . 3)))

(dolist (required-patch *required-patches*)
  (let ((existing-patch (assoc (car required-patch)
			    (cdr (assoc :system sys::*patches*))
			    :test #'string=)))
    (when (null existing-patch)
      (error "Could not find patch info for the ~s module."
	     (car required-patch)))
    (when (not (>= (second existing-patch) (cdr required-patch)))
      ;; The build patch number is NOT >= to the one we require
      (error "~
Expected version ~d of ~s but have version ~d.  Please update ~
your lisp with update.~a and then do the CG/JS installation again."
	     (cdr required-patch) (car required-patch)
	     (second existing-patch)
	     #+mswindows "exe"
	     #-mswindows "sh"))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; copy files

(defun copy (source dest)
  (cond
   ((file-directory-p source)
    (format t "Copy directory ~a~%" (enough-namestring source))
    (copy-directory source dest :quiet t))
   (t
    (format t "Copy file ~a~%" (enough-namestring source))
    (sys:copy-file source dest :verbose nil))))

(defvar *sys* (translate-logical-pathname (pathname "sys:")))

(cond
 ((excl::pathname-equalp (truename *sys*)
			 (path-pathname *load-truename*))
  (format t "Files are already in place, no copying requiring.~%"))
 (t ;; copy files, replacing them with new ones if they already exist
  (let (dest)
    (dolist (from *extra-files*)
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      (when (probe-file dest) (delete-file dest))
      (copy from dest))
    
    (dolist (from (list *cg2js-directory* *idejs-directory*))
      (setq dest (merge-pathnames (file-namestring from) *sys*))
      ;; now make it a directory pathname
      (setq dest (pathname-as-directory dest))

      (when (probe-file dest) (delete-directory-and-files dest))
      (copy (pathname-as-directory from) dest)))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; update develenv.cl to load CG/JS before the original version of CG

(defvar *setup-cgjs-loading* "sys:setup-cgjs-loading.cl")

;; Because users might use an ANSI lisp to install, have to make sure
;; the resulting file can be loaded into an ANSI and Modern lisp.
(with-open-file (s *setup-cgjs-loading* :direction :output
		 :if-exists :supersede)
  (format s "~
;; This file was created by install-cgjs.cl.
;; Please do not edit it.

")
  (dolist (dir (list "code.cg2js/" "code.idejs/"))
    (format s "
(let ((path (make-pathname
	     :type \"fasl\"
	     :directory (pathname-directory
			 (merge-pathnames
			  ~s
			  (translate-logical-pathname \"sys:\"))))))
  (format t \";; *require-search-list*: adding: ~~s~%\" path)
  (push path sys:*require-search-list*))

"
	    dir)))

(defvar *develenv.cl* (pathname "sys:develenv.cl"))

(when (not (probe-file *develenv.cl*))
  (setf (file-contents *develenv.cl*)
    ";; This file is loaded before images are rebuilt with update.sh/update.exe

"))

(let ((contents (file-contents *develenv.cl*)))
  (cond
   ((match-re
     (format nil "^#\\|\\|# \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl already correctly loads CG/JS.~%"))
   ((match-re
     (format nil "^#\\+ignore \\(load \"sys:~a"
	     (file-namestring *setup-cgjs-loading*))
     contents
     :multiple-lines t)
    (format t "develenv.cl: CG/JS disabled; will enable.~%")
    (setf (file-contents *develenv.cl*)
      (replace-re  contents
		  (format nil "^#\\+ignore *\\(load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  (format nil "#||# (load \"sys:~a"
			  (file-namestring *setup-cgjs-loading*))
		  :multiple-lines t
		  :count 1)))
   (t
    (format t "develenv.cl: adding CG/JS initialization.~%")
    (setf (file-contents *develenv.cl*)
      (concatenate 'simple-string
	contents
	(format nil "~

;; To disable the use of CG/JS and go back to the originally released
;; (and possibly patched) version of CG/IDE, change the #||# to
;; #+ignore on the following line and the rebuild images by running
;; update.sh or update.exe, depending on your platform:
#||# (load \"sys:~a\")~%~%"
		(file-namestring *setup-cgjs-loading*)))))))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; success!

(let ((msg (format nil "~
CG/JS installation successful!

NOTE: to use CG/JS you must rebuild images by running 'update.~a'
      in the Allegro CL directory (~a)."
		   #+mswindows "exe"
		   #-mswindows "sh"
		   *sys*)))
  #-mswindows (format t "~&~%~a~%" msg)
  #+mswindows (excl::internal-message-box msg "CG/JS Installation" :type :ok))
